{{ fullname | escape | underline}}

.. currentmodule:: {{ module }}

.. autofunction:: {{ objname }}

.. include:: /backreferences/{{module}}.{{objname}}.examples

.. raw:: html

    <div class="clearer"></div>
